
# XNATUM

XNATUM is a Python client that exposes in a simple way XNAT objects/functions. The aim is to make a simple Python package to everyone to use on top of Xnatpy. This reduces the need for the user to know the details of the REST API.

## Getting started

To install just use the setup.py normally:

```python setup.py install```

or install directly via pip:

```pip install xnatum```

## Dependencies

* [xnatpy](https://bitbucket.org/bigr_erasmusmc/xnatpy) >0.3.14

## Examples

You can find some code examples on how to use this package on the **examples** folder.

## Documentation

The official documentation will be soon avaiable at xnatum.readthedocs.org.

## Status

This package is currently been developed part of my thesis.